Clazz.declarePackage("JSV.api");
Clazz.declareInterface(JSV.api, "JSVAppletInterface");
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
